@@ -9,7 +9,8 @@ Simple Discord Slash Command extension for discord.py
 """
 
 from .client import SlashCommand
+from .model import SlashCommandOptionType
 from .model import SlashContext
 from .utils import manage_commands
 
-__version__ = "1.0.8"
+__version__ = "1.0.8.1"
