@@ -92,7 +92,7 @@ class SlashCommand:
                 else:
                     _cmd = {
                         "func": None,
-                        "description": x.base_desc,
+                        "description": x.base_description if x.base_description else "No Description.",
                         "auto_convert": {},
                         "guild_ids": x.allowed_guild_ids,
                         "api_options": [],
@@ -191,8 +191,8 @@ class SlashCommand:
                                 "options": sub_sub.options if sub_sub.options else []
                             }
                             base_dict["options"].append(_dict)
-                            if sub_sub.sub_group_desc:
-                                base_dict["description"] = sub_sub.sub_group_desc
+                            if sub_sub.subcommand_group_description:
+                                base_dict["description"] = sub_sub.subcommand_group_description
                         options.append(base_dict)
                 if selected.allowed_guild_ids:
                     for y in selected.allowed_guild_ids:
@@ -317,8 +317,8 @@ class SlashCommand:
                        subcommand_group=None,
                        name=None,
                        description: str = None,
-                       base_desc: str = None,
-                       sub_group_desc: str = None,
+                       base_description: str = None,
+                       subcommand_group_description: str = None,
                        auto_convert: dict = None,
                        guild_ids: typing.List[int] = None,
                        options: list = None):
@@ -335,10 +335,10 @@ class SlashCommand:
         :type name: str
         :param description: Description of the subcommand. Default ``None``.
         :type description: str
-        :param base_desc: Description of the base command. Default ``None``.
-        :type base_desc: str
-        :param sub_group_desc: Description of the subcommand_group. Default ``None``.
-        :type sub_group_desc: str
+        :param base_description: Description of the base command. Default ``None``.
+        :type base_description: str
+        :param subcommand_group_description: Description of the subcommand_group. Default ``None``.
+        :type subcommand_group_description: str
         :param auto_convert: Dictionary of how to convert option values. Default ``None``.
         :type auto_convert: dict
         :param guild_ids: List of guild ID of where the command will be used. Default ``None``, which will be global command.
@@ -352,7 +352,7 @@ class SlashCommand:
         name = name.lower()
         _cmd = {
             "func": None,
-            "description": base_desc,
+            "description": base_description if base_description else "No Description.",
             "auto_convert": {},
             "guild_ids": guild_ids,
             "api_options": [],
@@ -361,9 +361,9 @@ class SlashCommand:
         _sub = {
             "func": cmd,
             "name": name,
-            "description": description,
-            "base_desc": base_desc,
-            "sub_group_desc": sub_group_desc,
+            "description": description if description else "No Description.",
+            "base_desc": base_description if base_description else "No Description.",
+            "sub_group_desc": subcommand_group_description if subcommand_group_description else "No Description.",
             "auto_convert": auto_convert,
             "guild_ids": guild_ids,
             "api_options": options if options else []
@@ -427,9 +427,10 @@ class SlashCommand:
 
         .. code-block:: python
 
-            {"option_role": "role",       # For key put name of the option and for value put type of the option.
-             "option_user": 6,            # Also can use number for type
-             "option_channel": "CHANNEL"} # and all upper case.
+            {"option_role": "role",                      # For key put name of the option and for value put type of the option.
+             "option_user": SlashCommandOptionType.USER, # Also can use an enumeration member for the type
+             "option_user_two": 6,                       # or number
+             "option_channel": "CHANNEL"}                # or upper case string.
 
         :param name: Name of the slash command. Default name of the coroutine.
         :type name: str
@@ -469,7 +470,9 @@ class SlashCommand:
                    subcommand_group=None,
                    name=None,
                    description: str = None,
+                   base_description: str = None,
                    base_desc: str = None,
+                   subcommand_group_description: str = None,
                    sub_group_desc: str = None,
                    auto_convert: dict = None,
                    guild_ids: typing.List[int] = None,
@@ -496,10 +499,6 @@ class SlashCommand:
             async def _group_kick_user(ctx, user):
                 ...
 
-        .. note::
-            Unlike normal slash command, this doesn't support ``options`` arg, since it will be very complicated.\n
-            Also, subcommands won't be automatically registered to Discord API even if you set ``auto_register`` to ``True``.
-
         :param base: Name of the base command.
         :type base: str
         :param subcommand_group: Name of the subcommand group, if any. Default ``None`` which represents there is no sub group.
@@ -508,10 +507,12 @@ class SlashCommand:
         :type name: str
         :param description: Description of the subcommand. Default ``None``.
         :type description: str
-        :param base_desc: Description of the base command. Default ``None``.
-        :type base_desc: str
-        :param sub_group_desc: Description of the subcommand_group. Default ``None``.
-        :type sub_group_desc: str
+        :param base_description: Description of the base command. Default ``None``.
+        :type base_description: str
+        :param base_desc: Alias of ``base_description``.
+        :param subcommand_group_description: Description of the subcommand_group. Default ``None``.
+        :type subcommand_group_description: str
+        :param sub_group_desc: Alias of ``subcommand_group_description``.
         :param auto_convert: Dictionary of how to convert option values. Default ``None``.
         :type auto_convert: dict
         :param guild_ids: List of guild ID of where the command will be used. Default ``None``, which will be global command.
@@ -528,8 +529,11 @@ class SlashCommand:
                     raise Exception("You can't use subcommand or subcommand_group type!")
                 auto_convert[x["name"]] = x["type"]
 
+        base_description = base_description if base_description else base_desc
+        subcommand_group_description = subcommand_group_description if subcommand_group_description else sub_group_desc
+
         def wrapper(cmd):
-            self.add_subcommand(cmd, base, subcommand_group, name, description, base_desc, sub_group_desc, auto_convert, guild_ids, options)
+            self.add_subcommand(cmd, base, subcommand_group, name, description, base_description, subcommand_group_description, auto_convert, guild_ids, options)
             return cmd
 
         return wrapper
@@ -565,14 +569,17 @@ class SlashCommand:
         types = {
             "user": 0,
             "USER": 0,
-            6: 0,
+            model.SlashCommandOptionType.USER: 0,
             "6": 0,
+            6: 0,
             "channel": 1,
             "CHANNEL": 1,
-            7: 1,
+            model.SlashCommandOptionType.CHANNEL: 1,
             "7": 1,
+            7: 1,
             "role": 2,
             "ROLE": 2,
+            model.SlashCommandOptionType.ROLE: 2,
             8: 2,
             "8": 2
         }
